@@ -1,20 +1,27 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 import click
 
+if TYPE_CHECKING:
+    from hatch.cli.application import Application
+
 
 @click.command(short_help='Remove environments')
 @click.argument('env_name', default='default')
 @click.pass_context
-def remove(ctx, env_name):
+def remove(ctx: click.Context, env_name: str):
     """Remove environments."""
-    app = ctx.obj
+    app: Application = ctx.obj
     app.ensure_environment_plugin_dependencies()
 
-    if ctx.get_parameter_source('env_name').name == 'DEFAULT':
+    if (parameter_source := ctx.get_parameter_source('env_name')) is not None and parameter_source.name == 'DEFAULT':
         env_name = app.env
 
-    environments = (
-        list(app.project.config.matrices[env_name]['envs']) if env_name in app.project.config.matrices else [env_name]
-    )
+    environments = app.expand_environments(env_name)
+    if not environments:
+        app.abort(f'Environment `{env_name}` is not defined by project config')
 
     for env_name in environments:
         if env_name == app.env_active:
